Iris
####

Iris is an extension for the Mopidy music server. With support for Spotify, LastFM, Genius, Snapcast and many other extensions, Iris brings all your music into one user-friendly and unified web-based interface that works beautifully, no matter your device.

Built and maintained by James Barnsley.

.. image:: https://static.pepy.tech/personalized-badge/mopidy-iris?period=total&units=international_system&left_color=grey&right_color=green&left_text=Downloads
   :target: https://pepy.tech/project/mopidy-iris
.. image:: https://img.shields.io/pypi/v/mopidy-iris.svg?style=flat-square
   :target: https://pypi.org/project/Mopidy-Iris/
.. image:: https://img.shields.io/badge/donate-paypal-blue.svg?style=flat-square
   :target: https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=james%40barnsley%2enz&lc=NZ&item_name=James%20Barnsley&currency_code=USD&bn=PP%2dDonationsBF%3abtn_donate_LG%2egif%3aNonHosted

Features
********

- Full web-based interface controls for Mopidy
- Improved support for local libraries (powered by Mopidy-Local)
- Browse and manage your playlists and tracks
- Discover new, popular and related music (powered by Spotify)
- Multiple language support. `Want to provide a translation? <https://github.com/jaedb/Iris/wiki/Contributing#translations>`_
- Streaming controls with the ability to play audio from your browser (requires Snapcast)

Integrations
************

- `Spotify <https://developer.spotify.com/web-api/>`_
- `LastFM <https://www.last.fm/api>`_ for rich music metadata and artwork
- `Genius <https://docs.genius.com/>`_ for lyrics
- `Snapcast <https://github.com/badaix/snapcast/>`_ to stream audio to multiple devices

.. image:: https://raw.githubusercontent.com/jaedb/Iris/master/screenshot.jpg


Requirements
************

- Mopidy
- Mopidy-Spotify (recommended, not required)
- Mopidy-Local (recommended, not required)

Getting started
***************

- `Installation <https://github.com/jaedb/Iris/wiki/Getting-started#installing>`_
- `Debugging <https://github.com/jaedb/Iris/wiki/Advanced#debugging>`_
- `Issues and requests <https://github.com/jaedb/Iris/wiki/Support#before-you-log-an-issue>`_
- `Changelog <https://github.com/jaedb/Iris/releases>`_
